/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Injectable } from '@angular/core';
import {Observable} from "rxjs";
import {JsonObject} from "@angular/compiler-cli/ngcc/src/packages/entry_point";
import {HttpClient} from "@angular/common/http";

@Injectable({
  providedIn: 'root'
})
export class NotificationsService {

  constructor(
    private httpClient: HttpClient,
  ) { }

  /**
   * Gets JSON list of email templates
   * @return Observable<JsonObject>
   */
  public getEmailTemplates(): Observable<JsonObject> {
    const url = `/notify`;
    return this.httpClient.get<JsonObject>(url);
  }

  /**
   * Update email templates with edits
   * @param editParameters
   * @return Observable<JsonObject>
   */
  public updateEmailTemplates(editParameters: JsonObject): any {
    const url = `/notify/${editParameters.template_name}`;
    return this.httpClient.post<JsonObject>(url, JSON.stringify(editParameters));
  }

  /**
   * Send an email with the given parameters.
   * @param sendParameters
   * @return Observable<JsonObject>
   */
  public sendEmail(sendParameters: JsonObject): any {
    const url = `/notify/${sendParameters.template_name}/send`;
    return this.httpClient.post<JsonObject>(url, JSON.stringify(sendParameters));
  }
}
