# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""update ws_download_metrics view to use latest version's parameters for product locator

Revision ID: 35701e67ed06
Revises: 1443ac9c0f20
Create Date: 2021-06-01 14:35:34.950805

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "35701e67ed06"
down_revision = "1443ac9c0f20"
branch_labels = None
depends_on = None


def upgrade():
    op.execute(
        """
    CREATE OR REPLACE VIEW ws_download_metrics AS
    SELECT ce.capability_request_id as request_id,
       cr.capability_name as cap_name,
       ce.created_at as execution_created,
       ce.state as state,
       cv.parameters->>'product_locator' as product_locator,
       sp.filegroup_id,
       (CASE when (f.datasize is not null AND f.datasize != '-1') then f.datasize
             when (sum(f2.datasize) is not null) then sum(f2.datasize)
             ELSE sum(f3.filesize) end)::BIGINT as datasize
    FROM capability_executions ce
         JOIN capability_requests cr on cr.capability_request_id = ce.capability_request_id
         JOIN capability_versions cv on cr.capability_request_id = cv.capability_request_id
         JOIN science_products sp on cv.parameters->>'product_locator' = sp.science_product_locator
         Left Outer JOIN filegroups f on sp.filegroup_id = f.filegroup_id
         Left Outer Join filegroups f2 on sp.filegroup_id = f2.parent_filegroup_id
         Left OUTER JOIN files f3 on sp.filegroup_id = f3.filegroup
    WHERE cr.capability_name = 'test_download' AND cv.version_number = (SELECT MAX(version_number) from capability_versions WHERE cr.capability_request_id = capability_request_id)
    GROUP BY ce.capability_request_id, cr.capability_name, ce.created_at, ce.state, cv.parameters->>'product_locator',
         sp.filegroup_id, f.datasize
    """
    )


def downgrade():
    op.execute(
        """
    CREATE OR REPLACE VIEW ws_download_metrics AS
    SELECT ce.capability_request_id as request_id,
       cr.capability_name as cap_name,
       ce.created_at as execution_created,
       ce.state as state,
       cr.parameters->>'product_locator' as product_locator,
       sp.filegroup_id,
       (CASE when (f.datasize is not null AND f.datasize != '-1') then f.datasize
             when (sum(f2.datasize) is not null) then sum(f2.datasize)
             ELSE sum(f3.filesize) end)::BIGINT as datasize
    FROM capability_executions ce
         JOIN capability_requests cr on cr.capability_request_id = ce.capability_request_id
         JOIN science_products sp on parameters->>'product_locator' = sp.science_product_locator
         Left Outer JOIN filegroups f on sp.filegroup_id = f.filegroup_id
         Left Outer Join filegroups f2 on sp.filegroup_id = f2.parent_filegroup_id
         Left OUTER JOIN files f3 on sp.filegroup_id = f3.filegroup
    WHERE capability_name = 'test_download'
    GROUP BY ce.capability_request_id, cr.capability_name, ce.created_at, ce.state, cr.parameters->>'product_locator',
         sp.filegroup_id, f.datasize
    """
    )
