# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""multistage restore imaging scripts

Revision ID: bd32e3fa12ac
Revises: 4cb741e8606a
Create Date: 2021-10-08 15:48:15.278013

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "bd32e3fa12ac"
down_revision = "4cb741e8606a"
branch_labels = None
depends_on = None


fetch_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1 --product-locator $2
cd ../

"""

envoy_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR
{{#remote}}
export CAPO_PATH=.
export CAPO_PROFILE={{profile}}
{{/remote}}

./casa_envoy --integrated -i $1 $2

"""

deliver_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

./deliver -p ./products --prefix $1

"""

old_content = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit
./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1 --product-locator $2
cd ../
./casa_envoy --integrated -i $4 $5
./deliver -p ./products --prefix $3
"""


def upgrade():
    op.execute(
        """
        DELETE FROM workflow_templates WHERE filename='std_restore_imaging.sh'
        """
    )
    op.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES ('std_restore_imaging_fetch.sh', E'{fetch_content}', 'std_restore_imaging')
            """
    )
    op.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES ('std_restore_imaging_envoy.sh', E'{envoy_content}', 'std_restore_imaging')
            """
    )
    op.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES ('std_restore_imaging_deliver.sh', E'{deliver_content}', 'std_restore_imaging')
            """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflow_templates
        WHERE filename like ('std_restore_imaging_%.sh')
        AND workflow_name = 'std_restore_imaging'
        """
    )

    op.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES ('std_restore_imaging.sh', E'{old_content}', 'std_restore_imaging')
            """
    )
