# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""remove erroneous ExecuteWorkflow actions for QA

Revision ID: edf4886e1d9c
Revises: 10375ceec652
Create Date: 2021-11-23 11:55:32.679768

"""
from alembic import op

# revision identifiers, used by Alembic.
revision = "edf4886e1d9c"
down_revision = "10375ceec652"
branch_labels = None
depends_on = None


def upgrade():
    op.execute("DELETE FROM capability_state_actions WHERE action_type = 'ExecuteWorkflow' AND arguments = 'qa_pass'")
    op.execute("DELETE FROM capability_state_actions WHERE action_type = 'ExecuteWorkflow' AND arguments = 'qa_fail'")


def downgrade():
    add_back_erroneous_qa_pass_sql = """
    INSERT INTO capability_state_actions (transition_id, action_type, arguments)
    SELECT transition_id, 'ExecuteWorkflow', 'qa_pass'
    FROM capability_state_transitions
    WHERE pattern = 'type == qa_pass'
      AND capability_name = 'std_calibration'
    """
    add_back_erroneous_qa_fail_sql = """
    INSERT INTO capability_state_actions (transition_id, action_type, arguments)
    SELECT transition_id, 'ExecuteWorkflow', 'qa_fail'
    FROM capability_state_transitions
    WHERE pattern = 'type == qa_fail'
      AND capability_name = 'std_calibration'
    """
    op.execute(add_back_erroneous_qa_pass_sql)
    op.execute(add_back_erroneous_qa_fail_sql)
